-------------------------------------------------------------------------------
-- Title      : Clock Macro for VP50 Device
-- Project    : 
-------------------------------------------------------------------------------
-- File       : $RCSfile: clock_macro50.vhd,v $
-- Author     : Cray Canada
-- Company    : Cray Canada Inc.
-- Created    : 2004-06-29
-- Last update: 2004-06-29
-------------------------------------------------------------------------------
-- Description: Instantiates the proper clock macro for the VP50.
-------------------------------------------------------------------------------
-- Copyright (c) 2004 Cray Canada Inc.
-------------------------------------------------------------------------------
-- Revisions  :
-- $Log: clock_macro50.vhd,v $
-- Revision 1.1  2005/01/04 20:53:10 
-- Initial checkin.
--
-- Revision 1.1  2004/07/08 21:17:56 
-- Initial checkin.
--
-------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;

entity clock_macro is
  
  generic (
    dcm_location : string := "x0y0");
  port (
    clock1_in  : in  std_logic;
    clock2_in  : in  std_logic;
    clock1_out : out std_logic;
    clock2_out : out std_logic);

end entity clock_macro;

architecture struct of clock_macro is

  -----------------------------------------------------------------------------
  -- Declare Components
  -----------------------------------------------------------------------------
  attribute box_type : string;

  component dcmx0y0_2vp50 is
    port (
      clock1_in  : in  std_logic;
      clock2_in  : in  std_logic;
      clock1_out : out std_logic;
      clock2_out : out std_logic);
  end component dcmx0y0_2vp50;
  attribute box_type of dcmx0y0_2vp50 : component is "black_box";

  component dcmx1y0_2vp50 is
    port (
      clock1_in  : in  std_logic;
      clock2_in  : in  std_logic;
      clock1_out : out std_logic;
      clock2_out : out std_logic);
  end component dcmx1y0_2vp50;
  attribute box_type of dcmx1y0_2vp50 : component is "black_box";

  component dcmx2y0_2vp50 is
    port (
      clock1_in  : in  std_logic;
      clock2_in  : in  std_logic;
      clock1_out : out std_logic;
      clock2_out : out std_logic);
  end component dcmx2y0_2vp50;
  attribute box_type of dcmx2y0_2vp50 : component is "black_box";

  component dcmx3y0_2vp50 is
    port (
      clock1_in  : in  std_logic;
      clock2_in  : in  std_logic;
      clock1_out : out std_logic;
      clock2_out : out std_logic);
  end component dcmx3y0_2vp50;
  attribute box_type of dcmx3y0_2vp50 : component is "black_box";

begin  -- architecture struct

  -- These macros are provided by Xilinx to fix a bug with duty cycle
  -- distortion on high speed clocks. See XAPP685.
  x0y0_gen : if dcm_location = "x0y0" generate
    dcmx0y0_2vp50_inst : dcmx0y0_2vp50
      port map (
        clock1_in  => clock1_in,
        clock2_in  => clock2_in,
        clock1_out => clock1_out,
        clock2_out => clock2_out);
  end generate x0y0_gen;

  x1y0_gen : if dcm_location = "x1y0" generate
    dcmx0y0_2vp50_inst : dcmx1y0_2vp50
      port map (
        clock1_in  => clock1_in,
        clock2_in  => clock2_in,
        clock1_out => clock1_out,
        clock2_out => clock2_out);
  end generate x1y0_gen;

  x2y0_gen : if dcm_location = "x2y0" generate
    dcmx0y0_2vp50_inst : dcmx2y0_2vp50
      port map (
        clock1_in  => clock1_in,
        clock2_in  => clock2_in,
        clock1_out => clock1_out,
        clock2_out => clock2_out);
  end generate x2y0_gen;

  x3y0_gen : if dcm_location = "x3y0" generate
    dcmx0y0_2vp50_inst : dcmx3y0_2vp50
      port map (
        clock1_in  => clock1_in,
        clock2_in  => clock2_in,
        clock1_out => clock1_out,
        clock2_out => clock2_out);
  end generate x3y0_gen;
  

end architecture struct;
