--------------------------------------------------------------------------------
-- This file implements the threshold functionality of the filter module.
-- Threshold + 1 = the smallest value sent to writer.
--------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_misc.all;
use work.user_pkg.all;


entity filter is
	 port (
		reset_n 		: in  std_logic;
		user_clk 		: in  std_logic;
		valid 			: in  std_logic;
		stall			: in  std_logic;
		data_in 		: in  std_logic_vector(37 downto 0);
		index_in		: in  std_logic_vector(25 downto 0);
		threshold		: in  std_logic_vector(37 downto 0);

		data_valid		: out std_logic;
		data_out		: out std_logic_vector(63 downto 0)
	 );
end filter;

architecture rtl of filter is
	signal thresh : std_logic_vector(37 downto 0);
	signal thresh_is_set : std_logic;
begin
	do_stuff : process (reset_n, user_clk)
	begin
		if reset_n='0' then
			data_valid <= '0';
			data_out <= (others => '0');
			thresh <= (others => '0');
			thresh_is_set <= '0';
		elsif user_clk='1' and user_clk'event then
			if thresh_is_set/='1' then
				if threshold > 0 then
					thresh <= threshold;
					thresh_is_set <= '1';
				end if;
			end if;
			data_out <= index_in & data_in;
			if thresh(30 downto 0) < data_in(30 downto 0) and valid='1' then
				if thresh(31) = '0' then
					data_valid <= not data_in(31);
				else
					data_valid <= '1';
				end if;
			else
				data_valid <= '0';
			end if;
		end if;
	end process do_stuff;

end rtl;
