--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_misc.all;
use work.user_pkg.all;


entity reader is
	 port(
		reset_n     : in  std_logic;
		user_clk		: in  std_logic;
		stall			: in  std_logic;

		active		: in  std_logic;
		data_offset	: in  std_logic_vector(25 downto 3);

		out_valid	: out std_logic;
		data_out		: out std_logic_vector(7 downto 0);
		index_out	: out std_logic_vector(25 downto 0);

		-- sram interface
		dr_1        : in  std_logic_vector(71 downto 0);  -- read data 
		ar_1        : out std_logic_vector(19 downto 0);  -- read address
		r_n_1       : out std_logic;      -- Read strobe

		dr_2        : in  std_logic_vector(71 downto 0);  -- read data 
		ar_2        : out std_logic_vector(19 downto 0);  -- read address
		r_n_2       : out std_logic;      -- Read strobe

		dr_3        : in  std_logic_vector(71 downto 0);  -- read data 
		ar_3        : out std_logic_vector(19 downto 0);  -- read address
		r_n_3       : out std_logic;      -- Read strobe

		dr_4        : in  std_logic_vector(71 downto 0);  -- read data 
		ar_4        : out std_logic_vector(19 downto 0);  -- read address
		r_n_4       : out std_logic      -- Read strobe
	 );
end reader;

architecture rtl of reader is

signal current_index : std_logic_vector(25 downto 0);

signal out_valid_buffer : std_logic;
signal data_out_buffer : std_logic_vector(7 downto 0);
signal index_out_buffer : std_logic_vector(25 downto 0);

signal data_buffer_1, data_buffer_2, data_buffer_3, data_buffer_4 : std_logic_vector(63 downto 0);

begin

	prefetch : process (reset_n, user_clk)
		variable warmup : integer := 8;
	begin
		if reset_n='0' then
			r_n_1 <= '1';
			r_n_2 <= '1';
			r_n_3 <= '1';
			r_n_4 <= '1';

			ar_1 <= (others => '0');
			ar_2 <= (others => '0');
			ar_3 <= (others => '0');
			ar_4 <= (others => '0');

			out_valid <= '0';
			data_out <= (others => '0');
			index_out <= (others => '0');

			out_valid_buffer <= '0';
			data_out_buffer <= (others => '0');
			index_out_buffer <= (others => '0');

			current_index <= (others => '0');
		elsif user_clk='1' and user_clk'event then
			if active='1' then
				r_n_1 <= '0';
				r_n_2 <= '0';
				r_n_3 <= '0';
				r_n_4 <= '0';

				if current_index(4 downto 3) > "00" then
					ar_1 <= current_index(24 downto 5) + 1;
				else
					ar_1 <= current_index(24 downto 5);
				end if;

				if current_index(4 downto 3) > "01" then
					ar_2 <= current_index(24 downto 5) + 1;
				else
					ar_2 <= current_index(24 downto 5);
				end if;

				if current_index(4 downto 3) > "10" then
					ar_3 <= current_index(24 downto 5) + 1;
				else
					ar_3 <= current_index(24 downto 5);
				end if;

				ar_4 <= current_index(24 downto 5);

				data_buffer_1 <= extract_data(dr_1);
				data_buffer_2 <= extract_data(dr_2);
				data_buffer_3 <= extract_data(dr_3);
				data_buffer_4 <= extract_data(dr_4);

				--data_buffer_1 <= X"0000000000000000";
				--data_buffer_2 <= X"0000000000000000";
				--data_buffer_3 <= X"0000000000000000";
				--data_buffer_4 <= X"0000000000000000";

				if current_index(4 downto 3) = "00" then
					--data_out_buffer <= dr_1(conv_integer(current_index(2 downto 0))*9+7 downto conv_integer(current_index(2 downto 0))*9);
					case current_index(2 downto 0) is
						when "000" =>
							data_out_buffer <= data_buffer_1(7 downto 0);	
						when "001" =>
							data_out_buffer <= data_buffer_1(15 downto 8);	
						when "010" =>
							data_out_buffer <= data_buffer_1(23 downto 16);	
						when "011" =>
							data_out_buffer <= data_buffer_1(31 downto 24);	
						when "100" =>
							data_out_buffer <= data_buffer_1(39 downto 32);	
						when "101" =>
							data_out_buffer <= data_buffer_1(47 downto 40);	
						when "110" =>
							data_out_buffer <= data_buffer_1(55 downto 48);	
						when "111" =>
							data_out_buffer <= data_buffer_1(63 downto 56);	
						when others =>
							null;
					end case;
				elsif current_index(4 downto 3) = "01" then
					--data_out_buffer <= dr_2(conv_integer(current_index(2 downto 0))*9+7 downto conv_integer(current_index(2 downto 0))*9);
					case current_index(2 downto 0) is
						when "000" =>
							data_out_buffer <= data_buffer_2(7 downto 0);	
						when "001" =>
							data_out_buffer <= data_buffer_2(15 downto 8);	
						when "010" =>
							data_out_buffer <= data_buffer_2(23 downto 16);	
						when "011" =>
							data_out_buffer <= data_buffer_2(31 downto 24);	
						when "100" =>
							data_out_buffer <= data_buffer_2(39 downto 32);	
						when "101" =>
							data_out_buffer <= data_buffer_2(47 downto 40);	
						when "110" =>
							data_out_buffer <= data_buffer_2(55 downto 48);	
						when "111" =>
							data_out_buffer <= data_buffer_2(63 downto 56);	
						when others =>
							null;
					end case;
				elsif current_index(4 downto 3) = "10" then
					--data_out_buffer <= dr_3(conv_integer(current_index(2 downto 0))*9+7 downto conv_integer(current_index(2 downto 0))*9);
					case current_index(2 downto 0) is
						when "000" =>
							data_out_buffer <= data_buffer_3(7 downto 0);	
						when "001" =>
							data_out_buffer <= data_buffer_3(15 downto 8);	
						when "010" =>
							data_out_buffer <= data_buffer_3(23 downto 16);	
						when "011" =>
							data_out_buffer <= data_buffer_3(31 downto 24);	
						when "100" =>
							data_out_buffer <= data_buffer_3(39 downto 32);	
						when "101" =>
							data_out_buffer <= data_buffer_3(47 downto 40);	
						when "110" =>
							data_out_buffer <= data_buffer_3(55 downto 48);	
						when "111" =>
							data_out_buffer <= data_buffer_3(63 downto 56);	
						when others =>
							null;
					end case;
				else
					--data_out_buffer <= dr_4(conv_integer(current_index(2 downto 0))*9+7 downto conv_integer(current_index(2 downto 0))*9);
					case current_index(2 downto 0) is
						when "000" =>
							data_out_buffer <= data_buffer_4(7 downto 0);	
						when "001" =>
							data_out_buffer <= data_buffer_4(15 downto 8);	
						when "010" =>
							data_out_buffer <= data_buffer_4(23 downto 16);	
						when "011" =>
							data_out_buffer <= data_buffer_4(31 downto 24);	
						when "100" =>
							data_out_buffer <= data_buffer_4(39 downto 32);	
						when "101" =>
							data_out_buffer <= data_buffer_4(47 downto 40);	
						when "110" =>
							data_out_buffer <= data_buffer_4(55 downto 48);	
						when "111" =>
							data_out_buffer <= data_buffer_4(63 downto 56);	
						when others =>
							null;
					end case;
				end if;

				--data_out_buffer <= X"01";
				index_out_buffer <= current_index;

				if warmup = 0 then
					out_valid_buffer <= '1';

					if stall='0' then
						current_index <= current_index + 1;
						out_valid <= out_valid_buffer;
						data_out <= data_out_buffer;
						index_out <= index_out_buffer;
					end if;
				else
					warmup := warmup - 1;
					out_valid <= '0';					
				end if;
			else
				out_valid_buffer <= '0';
				data_out_buffer <= (others => '0');
				index_out_buffer <= (others => '0');

				out_valid <= '0';
				data_out <= (others => '0');
				index_out <= (others => '0');

				warmup := 8;

				r_n_1 <= '1';
				r_n_2 <= '1';
				r_n_3 <= '1';
				r_n_4 <= '1';

				ar_1 <= (others => '0');
				ar_2 <= (others => '0');
				ar_3 <= (others => '0');
				ar_4 <= (others => '0');

				current_index(22 downto 0) <= data_offset;
			end if;
		end if;
	end process prefetch;
end rtl;
