-------------------------------------------------------------------------------
-- Title      : User Application Package File
-- Project    : 
-------------------------------------------------------------------------------
-- File       : $RCSfile: user_pkg.vhd,v $
-- Author     : Cray Canada
-- Company    : Cray Canada Inc.
-- Created    : 2005-01-04
-- Last update: 2005-01-04
-------------------------------------------------------------------------------
-- Description: This package file is intended to contain constants, types,
-- functions and procedures used in multiple locations throughout the design.
-------------------------------------------------------------------------------
-- Copyright (c) 2005 Cray Canada Inc.
-------------------------------------------------------------------------------
-- Revisions  :
-- $Log: user_pkg.vhd,v $
-- Revision 1.1  2005/01/04 20:53:11 
-- Initial checkin.
--
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_misc.all;
use ieee.numeric_std.all;

package user_pkg is

  -----------------------------------------------------------------------------
  -- Declare Constants
  -----------------------------------------------------------------------------

  -- Declare the template design base number, variant number, revision number,
  -- and compile number.  
  constant c_tmpl_base : std_logic_vector(15 downto 0) := x"0008";
  constant c_tmpl_var  : std_logic_vector(7 downto 0)  := x"01";
  constant c_tmpl_rev  : std_logic_vector(7 downto 0)  := x"01";
  constant c_tmpl_comp : std_logic_vector(7 downto 0)  := x"06";

  -- Declare constant threshold for filter
--  constant threshold : std_logic_vector(37 downto 0) := "00000000000000000000000000000000001111";

  -----------------------------------------------------------------------------
  -- Declare Types
  -----------------------------------------------------------------------------

	type buffer_array is array(0 to 7) of std_logic_vector (63 downto 0);
	type elem_array is array(0 to 7) of std_logic_vector(7 downto 0);
	type lu_table is array(0 to 31) of std_logic_vector (31 downto 0);

--	constant pwm_table: lu_table;-- :=
--	(
--     X"00000007", X"00000032", X"000000AD", X"000000FF", X"000000AD", X"000000BB", X"000000DA", X"00000017",
--     X"000000AD", X"000000BB", X"000000DA", X"00000017", X"00000030", X"000000AA", X"000000DB", X"000000EA",
--     X"00000030", X"000000AA", X"000000DB", X"000000EA", X"0000001D", X"00000010", X"00000012", X"00000013",
--     X"0000001D", X"00000010", X"00000012", X"00000013", X"00000007", X"00000032", X"000000AD", X"000000FF"
--	);


  -----------------------------------------------------------------------------
  -- Declare functions and procedures.
  -----------------------------------------------------------------------------
  -- The following functions interleave the parity bits with the data bits to
  -- facilitate reading and writing the QDR II RAM.
  function insert_parity (
    data : std_logic_vector(63 downto 0))
    return std_logic_vector;

  function generate_parity (
    data : std_logic_vector(63 downto 0))
    return std_logic_vector;

  function extract_parity (
    data : std_logic_vector(71 downto 0))
    return std_logic_vector;

  function extract_data (
    data : std_logic_vector(71 downto 0))
    return std_logic_vector;

	-- PWM stuff
  impure function pwm_lookup (
    col : std_logic_vector(2 downto 0);
    data : std_logic_vector(6 downto 0);
	 pwm_table : lu_table)
  return std_logic_vector;

  procedure pwm_set (
	col : in std_logic_vector(2 downto 0);
	row : in std_logic_vector(6 downto 0);
	val : in std_logic_vector(31 downto 0);
	signal pwm_table : inout lu_table
  );

end package user_pkg;

package body user_pkg is
  
  -- This function will calculate the parity byte for a 64 bit data word and
  -- return the parity byte.
  function generate_parity (
    data : std_logic_vector(63 downto 0))
    return std_logic_vector is
    variable v_result : std_logic_vector(7 downto 0);
  begin  -- function insert_parity
    v_result := xnor_reduce(data(63 downto 56)) &
                xnor_reduce(data(55 downto 48)) &
                xnor_reduce(data(47 downto 40)) &
                xnor_reduce(data(39 downto 32)) &
                xnor_reduce(data(31 downto 24)) &
                xnor_reduce(data(23 downto 16)) &
                xnor_reduce(data(15 downto 8)) &
                xnor_reduce(data(7 downto 0));
    return v_result;
  end function generate_parity;

  -- This function will calculate and interleave odd parity for a 64 bit data
  -- word.
  function insert_parity (
    data : std_logic_vector(63 downto 0))
    return std_logic_vector is
    variable v_result : std_logic_vector(71 downto 0);
  begin  -- function insert_parity
    v_result := xnor_reduce(data(63 downto 56)) & data(63 downto 56) &
                xnor_reduce(data(55 downto 48)) & data(55 downto 48) &
                xnor_reduce(data(47 downto 40)) & data(47 downto 40) &
                xnor_reduce(data(39 downto 32)) & data(39 downto 32) &
                xnor_reduce(data(31 downto 24)) & data(31 downto 24) &
                xnor_reduce(data(23 downto 16)) & data(23 downto 16) &
                xnor_reduce(data(15 downto 8)) & data(15 downto 8) &
                xnor_reduce(data(7 downto 0)) & data(7 downto 0);
    return v_result;
  end function insert_parity;

  -- This function will extract the interleaved parity bits from a 72 bit data
  -- word.
  function extract_parity (
    data : std_logic_vector(71 downto 0))
    return std_logic_vector is
    variable v_result : std_logic_vector(7 downto 0);
  begin  -- function extract_parity
    v_result := data(71) & data(62) & data(53) & data(44) &
                data(35) & data(26) & data(17) & data(8);
    return v_result;
  end function extract_parity;
  
  -- This function will extract the 64 bit data word from a 72 bit data word
  -- containing interleaved parity.
  function extract_data (
    data : std_logic_vector(71 downto 0))
    return std_logic_vector is
    variable v_result : std_logic_vector(63 downto 0);
  begin  -- function extract_data
    v_result := data(70 downto 63) &
                data(61 downto 54) &
                data(52 downto 45) &
                data(43 downto 36) &
                data(34 downto 27) &
                data(25 downto 18) &
                data(16 downto 9) &
                data(7 downto 0);
    return v_result;
  end function extract_data;
							  
	impure function pwm_lookup (
		col : std_logic_vector(2 downto 0);
		data : std_logic_vector(6 downto 0);
		pwm_table : lu_table )
		return std_logic_vector is
		variable v_result : std_logic_vector(31 downto 0);
	begin
		case col is
			when "000" =>
				case data is
					when "0000000" =>
						v_result := pwm_table(0);
					when "0000001" =>
						v_result := pwm_table(8);
					when "0000010" =>
						v_result := pwm_table(16);
					when "0000011" =>
						v_result := pwm_table(24);
					when others =>
						null;
				end case;
			when "001" =>
				case data is
					when "0000000" =>
						v_result := pwm_table(1);
					when "0000001" =>
						v_result := pwm_table(9);
					when "0000010" =>
						v_result := pwm_table(17);
					when "0000011" =>
						v_result := pwm_table(25);
					when others =>
						null;
				end case;
			when "010" =>
				case data is
					when "0000000" =>
						v_result := pwm_table(2);
					when "0000001" =>				  
						v_result := pwm_table(10);
					when "0000010" =>
						v_result := pwm_table(18);
					when "0000011" =>
						v_result := pwm_table(26);
					when others =>
						null;
				end case;
			when "011" =>
				case data is
					when "0000000" =>
						v_result := pwm_table(3);
					when "0000001" =>
						v_result := pwm_table(11);
					when "0000010" =>
						v_result := pwm_table(19);
					when "0000011" =>
						v_result := pwm_table(27);
					when others =>
						null;
				end case;
			when "100" =>
				case data is
					when "0000000" =>
						v_result := pwm_table(4);
					when "0000001" =>
						v_result := pwm_table(12);
					when "0000010" =>
						v_result := pwm_table(20);
					when "0000011" =>
						v_result := pwm_table(28);
					when others =>
						null;
				end case;
			when "101" =>
				case data is
					when "0000000" =>
						v_result := pwm_table(5);
					when "0000001" =>
						v_result := pwm_table(13);
					when "0000010" =>
						v_result := pwm_table(21);
					when "0000011" =>
						v_result := pwm_table(29);
					when others =>
						null;
				end case;
			when "110" =>
				case data is
					when "0000000" =>
						v_result := pwm_table(6);
					when "0000001" =>				  
						v_result := pwm_table(14);
					when "0000010" =>
						v_result := pwm_table(22);
					when "0000011" =>
						v_result := pwm_table(30);
					when others =>
						null;
				end case;
			when "111" =>
				case data is
					when "0000000" =>
						v_result := pwm_table(7);
					when "0000001" =>
						v_result := pwm_table(15);
					when "0000010" =>
						v_result := pwm_table(23);
					when "0000011" =>
						v_result := pwm_table(31);
					when others =>
						null;
				end case;
			when others =>
				null;
		end case;
	
		return v_result;
	end function pwm_lookup;

	procedure pwm_set (
		col : in std_logic_vector(2 downto 0);
		row : in std_logic_vector(6 downto 0);
		val : in std_logic_vector(31 downto 0);
		signal pwm_table : inout lu_table ) is
	begin
		case col is
			when "000" =>
				case row is
					when "0000000" =>
						pwm_table(0) <= val;
					when "0000001" =>
						pwm_table(8) <= val;
					when "0000010" =>
						pwm_table(16) <= val;
					when "0000011" =>
						pwm_table(24) <= val;
					when others =>
						null;
				end case;
			when "001" =>
				case row is
					when "0000000" =>
						pwm_table(1) <= val;
					when "0000001" =>
						pwm_table(9) <= val;
					when "0000010" =>
						pwm_table(17) <= val;
					when "0000011" =>
						pwm_table(25) <= val;
					when others =>
						null;
				end case;
			when "010" =>
				case row is
					when "0000000" =>
						pwm_table(2) <= val;
					when "0000001" =>				  
						pwm_table(10) <= val;
					when "0000010" =>
						pwm_table(18) <= val;
					when "0000011" =>
						pwm_table(26) <= val;
					when others =>
						null;
				end case;
			when "011" =>
				case row is
					when "0000000" =>
						pwm_table(3) <= val;
					when "0000001" =>
						pwm_table(11) <= val;
					when "0000010" =>
						pwm_table(19) <= val;
					when "0000011" =>
						pwm_table(27) <= val;
					when others =>
						null;
				end case;
			when "100" =>
				case row is
					when "0000000" =>
						pwm_table(4) <= val;
					when "0000001" =>
						pwm_table(12) <= val;
					when "0000010" =>
						pwm_table(20) <= val;
					when "0000011" =>
						pwm_table(28) <= val;
					when others =>
						null;
				end case;
			when "101" =>
				case row is
					when "0000000" =>
						pwm_table(5) <= val;
					when "0000001" =>
						pwm_table(13) <= val;
					when "0000010" =>
						pwm_table(21) <= val;
					when "0000011" =>
						pwm_table(29) <= val;
					when others =>
						null;
				end case;
			when "110" =>
				case row is
					when "0000000" =>
						pwm_table(6) <= val;
					when "0000001" =>				  
						pwm_table(14) <= val;
					when "0000010" =>
						pwm_table(22) <= val;
					when "0000011" =>
						pwm_table(30) <= val;
					when others =>
						null;
				end case;
			when "111" =>
				case row is
					when "0000000" =>
						pwm_table(7) <= val;
					when "0000001" =>
						pwm_table(15) <= val;
					when "0000010" =>
						pwm_table(23) <= val;
					when "0000011" =>
						pwm_table(31) <= val;
					when others =>
						null;
				end case;
			when others =>
				null;
		end case;
	end procedure pwm_set;

end package body user_pkg;
