-------------------------------------------------------------------------------
-- Title      : Test Bench for Application Acceleration FPGA
-- Project    : 
-------------------------------------------------------------------------------
-- File       : $RCSfile: top_tb.vhd,v $
-- Author     : Cray Canada
-- Company    : Cray Canada Inc.
-- Created    : 2005-01-04
-- Last update: 2005-02-10
-------------------------------------------------------------------------------
-- Description: This is a test bench file for simulating an application
-- acceleration FPGA design.  It instantiates the Acceleration FPGA and 
-- VHDL source models for the fabric interface, host interface, and the
-- external QDR II RAMs.
-------------------------------------------------------------------------------
-- Copyright (c) 2005 Cray Canada Inc.
-------------------------------------------------------------------------------
-- Revisions  :
-- $Log: top_tb.vhd,v $
-- Revision 1.2  2005/02/11 01:42:19 
-- Removed host bus model.
--
-- Revision 1.1  2005/01/04 20:54:11 
-- Initial checkin.
--
-------------------------------------------------------------------------------
library ieee, top, rt, qdr;
use ieee.std_logic_1164.all;
use top.all;
use rt.all;
use qdr.all;

-------------------------------------------------------------------------------

entity top_tb is
  generic (
    fabric_input   : string := "tc_01/fabric.in";
    fabric_output  : string := "tc_01/fabric.out");
end entity top_tb;

-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
-- Declare the components
-------------------------------------------------------------------------------

architecture behave of top_tb is

  component top is
    port (
      glbl_reset_n : in    std_logic;
      rt_clk_p     : in    std_logic;
      rt_clk_n     : in    std_logic;
      rkta_clk_p   : in    std_logic;
      rkta_clk_n   : in    std_logic;
      rktb_clk_p   : in    std_logic;
      rktb_clk_n   : in    std_logic;
      prog_clk_p   : in    std_logic;
      prog_clk_n   : in    std_logic;
      rt_rx_clk_p  : in    std_logic;
      rt_rx_clk_n  : in    std_logic;
      rt_rx_ctl_p  : in    std_logic;
      rt_rx_ctl_n  : in    std_logic;
      rt_rx_cad_p  : in    std_logic_vector(15 downto 0);
      rt_rx_cad_n  : in    std_logic_vector(15 downto 0);
      rt_rx_par_p  : in    std_logic_vector(1 downto 0);
      rt_rx_par_n  : in    std_logic_vector(1 downto 0);
      rt_tx_clk_p  : out   std_logic;
      rt_tx_clk_n  : out   std_logic;
      rt_tx_ctl_p  : out   std_logic;
      rt_tx_ctl_n  : out   std_logic;
      rt_tx_cad_p  : out   std_logic_vector(15 downto 0);
      rt_tx_cad_n  : out   std_logic_vector(15 downto 0);
      rt_tx_par_p  : out   std_logic_vector(1 downto 0);
      rt_tx_par_n  : out   std_logic_vector(1 downto 0);
      host_cs_n    : in    std_logic;
      host_as      : in    std_logic;
      host_rw      : in    std_logic;
      host_par     : inout std_logic;
      host_ad      : inout std_logic_vector(7 downto 0);
      host_int_n   : out   std_logic;
      s_clock      : out   std_logic;
      s_data       : out   std_logic;
      s_load       : out   std_logic;
      np_load      : out   std_logic;
      k_copy_out   : out   std_logic;
      k_copy_in    : in    std_logic;
      qdr_rfb_n_1  : in    std_logic;
      qdr_dr_1     : in    std_logic_vector(35 downto 0);
      qdr_dw_1     : out   std_logic_vector(35 downto 0);
      qdr_sa_1     : out   std_logic_vector(19 downto 0);
      qdr_r_n_1    : out   std_logic;
      qdr_w_n_1    : out   std_logic;
      qdr_bw_n_1   : out   std_logic_vector(3 downto 0);
      qdr_k_1      : out   std_logic;
      qdr_k_n_1    : out   std_logic;
      qdr_cq_1     : in    std_logic;
      qdr_rext_n_1 : out   std_logic;
      qdr_doff_n_1 : out   std_logic;
      qdr_rfb_n_2  : in    std_logic;
      qdr_dr_2     : in    std_logic_vector(35 downto 0);
      qdr_dw_2     : out   std_logic_vector(35 downto 0);
      qdr_sa_2     : out   std_logic_vector(19 downto 0);
      qdr_r_n_2    : out   std_logic;
      qdr_w_n_2    : out   std_logic;
      qdr_bw_n_2   : out   std_logic_vector(3 downto 0);
      qdr_k_2      : out   std_logic;
      qdr_k_n_2    : out   std_logic;
      qdr_cq_2     : in    std_logic;
      qdr_rext_n_2 : out   std_logic;
      qdr_doff_n_2 : out   std_logic;
      qdr_rfb_n_3  : in    std_logic;
      qdr_dr_3     : in    std_logic_vector(35 downto 0);
      qdr_dw_3     : out   std_logic_vector(35 downto 0);
      qdr_sa_3     : out   std_logic_vector(19 downto 0);
      qdr_r_n_3    : out   std_logic;
      qdr_w_n_3    : out   std_logic;
      qdr_bw_n_3   : out   std_logic_vector(3 downto 0);
      qdr_k_3      : out   std_logic;
      qdr_k_n_3    : out   std_logic;
      qdr_cq_3     : in    std_logic;
      qdr_rext_n_3 : out   std_logic;
      qdr_doff_n_3 : out   std_logic;
      qdr_rfb_n_4  : in    std_logic;
      qdr_dr_4     : in    std_logic_vector(35 downto 0);
      qdr_dw_4     : out   std_logic_vector(35 downto 0);
      qdr_sa_4     : out   std_logic_vector(19 downto 0);
      qdr_r_n_4    : out   std_logic;
      qdr_w_n_4    : out   std_logic;
      qdr_bw_n_4   : out   std_logic_vector(3 downto 0);
      qdr_k_4      : out   std_logic;
      qdr_k_n_4    : out   std_logic;
      qdr_cq_4     : in    std_logic;
      qdr_rext_n_4 : out   std_logic;
      qdr_doff_n_4 : out   std_logic);
  end component top;

  component fabric_model is
    generic (
      fabric_input  : string;
      fabric_output : string);
    port (
      reset_n     : in  std_logic;
      ht_rx_clk_p : in  std_logic;
      ht_rx_clk_n : in  std_logic;
      ht_rx_ctl_p : in  std_logic;
      ht_rx_ctl_n : in  std_logic;
      ht_rx_cad_p : in  std_logic_vector(15 downto 0);
      ht_rx_cad_n : in  std_logic_vector(15 downto 0);
      ht_rx_par_p : in  std_logic_vector(1 downto 0);
      ht_rx_par_n : in  std_logic_vector(1 downto 0);
      ht_tx_clk_p : out std_logic;
      ht_tx_clk_n : out std_logic;
      ht_tx_ctl_p : out std_logic;
      ht_tx_ctl_n : out std_logic;
      ht_tx_cad_p : out std_logic_vector(15 downto 0);
      ht_tx_cad_n : out std_logic_vector(15 downto 0);
      ht_tx_par_p : out std_logic_vector(1 downto 0);
      ht_tx_par_n : out std_logic_vector(1 downto 0));
  end component fabric_model;

  component cy7c1314v18 is
    port (
      d     : in  std_logic_vector;
      q     : out std_logic_vector;
      a     : in  std_logic_vector;
      rps_n : in  std_logic;
      wps_n : in  std_logic;
      bws_n : in  std_logic_vector;
      k     : in  std_logic;
      k_n   : in  std_logic;
      c     : in  std_logic;
      c_n   : in  std_logic;
      cq    : out std_logic;
      cq_n  : out std_logic); 
  end component cy7c1314v18;

  -----------------------------------------------------------------------------
  -- Declare constants
  -----------------------------------------------------------------------------
  constant iob_delay : time := 2500 ps;
  constant fb_delay  : time := iob_delay + 650 ps;
  
  -----------------------------------------------------------------------------
  -- Declare the signals
  -----------------------------------------------------------------------------
  signal glbl_reset_n : std_logic := '0';
  signal rt_clk_p     : std_logic := '0';
  signal rt_clk_n     : std_logic := '1';
  signal rkta_clk_p   : std_logic := '0';
  signal rkta_clk_n   : std_logic := '1';
  signal rktb_clk_p   : std_logic := '0';
  signal rktb_clk_n   : std_logic := '1';
  signal prog_clk_p   : std_logic := '0';
  signal prog_clk_n   : std_logic := '1';
  signal host_clk     : std_logic := '0';
  signal rt_rx_clk_p  : std_logic;
  signal rt_rx_clk_n  : std_logic;
  signal rt_rx_ctl_p  : std_logic;
  signal rt_rx_ctl_n  : std_logic;
  signal rt_rx_cad_p  : std_logic_vector(15 downto 0);
  signal rt_rx_cad_n  : std_logic_vector(15 downto 0);
  signal rt_rx_par_p  : std_logic_vector(1 downto 0);
  signal rt_rx_par_n  : std_logic_vector(1 downto 0);
  signal rt_tx_clk_p  : std_logic;
  signal rt_tx_clk_n  : std_logic;
  signal rt_tx_ctl_p  : std_logic;
  signal rt_tx_ctl_n  : std_logic;
  signal rt_tx_cad_p  : std_logic_vector(15 downto 0);
  signal rt_tx_cad_n  : std_logic_vector(15 downto 0);
  signal rt_tx_par_p  : std_logic_vector(1 downto 0);
  signal rt_tx_par_n  : std_logic_vector(1 downto 0);
  signal host_cs_n    : std_logic;
  signal host_as      : std_logic;
  signal host_rw      : std_logic;
  signal host_par     : std_logic;
  signal host_ad      : std_logic_vector(7 downto 0);
  signal host_int_n   : std_logic;
  signal k_copy_out   : std_logic;
  signal k_copy_in    : std_logic;
  signal s_clock      : std_logic;
  signal s_data       : std_logic;
  signal s_load       : std_logic;
  signal np_load      : std_logic;
  signal qdr_dr_1     : std_logic_vector(35 downto 0);
  signal qdr_dw_1     : std_logic_vector(35 downto 0);
  signal qdr_sa_1     : std_logic_vector(19 downto 0);
  signal qdr_r_n_1    : std_logic;
  signal qdr_w_n_1    : std_logic;
  signal qdr_bw_n_1   : std_logic_vector(3 downto 0);
  signal qdr_k_1      : std_logic;
  signal qdr_k_n_1    : std_logic;
  signal qdr_cq_1     : std_logic;
  signal qdr_rext_n_1 : std_logic;
  signal qdr_doff_n_1 : std_logic;
  signal qdr_dr_2     : std_logic_vector(35 downto 0);
  signal qdr_dw_2     : std_logic_vector(35 downto 0);
  signal qdr_sa_2     : std_logic_vector(19 downto 0);
  signal qdr_r_n_2    : std_logic;
  signal qdr_w_n_2    : std_logic;
  signal qdr_bw_n_2   : std_logic_vector(3 downto 0);
  signal qdr_k_2      : std_logic;
  signal qdr_k_n_2    : std_logic;
  signal qdr_cq_2     : std_logic;
  signal qdr_rext_n_2 : std_logic;
  signal qdr_doff_n_2 : std_logic;
  signal qdr_dr_3     : std_logic_vector(35 downto 0);
  signal qdr_dw_3     : std_logic_vector(35 downto 0);
  signal qdr_sa_3     : std_logic_vector(19 downto 0);
  signal qdr_r_n_3    : std_logic;
  signal qdr_w_n_3    : std_logic;
  signal qdr_bw_n_3   : std_logic_vector(3 downto 0);
  signal qdr_k_3      : std_logic;
  signal qdr_k_n_3    : std_logic;
  signal qdr_cq_3     : std_logic;
  signal qdr_rext_n_3 : std_logic;
  signal qdr_doff_n_3 : std_logic;
  signal qdr_dr_4     : std_logic_vector(35 downto 0);
  signal qdr_dw_4     : std_logic_vector(35 downto 0);
  signal qdr_sa_4     : std_logic_vector(19 downto 0);
  signal qdr_r_n_4    : std_logic;
  signal qdr_w_n_4    : std_logic;
  signal qdr_bw_n_4   : std_logic_vector(3 downto 0);
  signal qdr_k_4      : std_logic;
  signal qdr_k_n_4    : std_logic;
  signal qdr_cq_4     : std_logic;
  signal qdr_rext_n_4 : std_logic;
  signal qdr_doff_n_4 : std_logic;

  signal qdr_k_1_buf      : std_logic;
  signal qdr_k_n_1_buf    : std_logic;
  signal qdr_dw_1_buf     : std_logic_vector(35 downto 0);
  signal qdr_sa_1_buf     : std_logic_vector(19 downto 0);
  signal qdr_r_n_1_buf    : std_logic;
  signal qdr_w_n_1_buf    : std_logic;
  signal qdr_bw_n_1_buf   : std_logic_vector(3 downto 0);
  signal qdr_rext_n_1_buf : std_logic;

  signal qdr_k_2_buf      : std_logic;
  signal qdr_k_n_2_buf    : std_logic;
  signal qdr_dw_2_buf     : std_logic_vector(35 downto 0);
  signal qdr_sa_2_buf     : std_logic_vector(19 downto 0);
  signal qdr_r_n_2_buf    : std_logic;
  signal qdr_w_n_2_buf    : std_logic;
  signal qdr_bw_n_2_buf   : std_logic_vector(3 downto 0);
  signal qdr_rext_n_2_buf : std_logic;

  signal qdr_k_3_buf      : std_logic;
  signal qdr_k_n_3_buf    : std_logic;
  signal qdr_dw_3_buf     : std_logic_vector(35 downto 0);
  signal qdr_sa_3_buf     : std_logic_vector(19 downto 0);
  signal qdr_r_n_3_buf    : std_logic;
  signal qdr_w_n_3_buf    : std_logic;
  signal qdr_bw_n_3_buf   : std_logic_vector(3 downto 0);
  signal qdr_rext_n_3_buf : std_logic;

  signal qdr_k_4_buf      : std_logic;
  signal qdr_k_n_4_buf    : std_logic;
  signal qdr_dw_4_buf     : std_logic_vector(35 downto 0);
  signal qdr_sa_4_buf     : std_logic_vector(19 downto 0);
  signal qdr_r_n_4_buf    : std_logic;
  signal qdr_w_n_4_buf    : std_logic;
  signal qdr_bw_n_4_buf   : std_logic_vector(3 downto 0);
  signal qdr_rext_n_4_buf : std_logic;
  

  signal hobit_reset_n : std_logic := '0';
  
begin  -- architecture behave

  rt_clk_p      <= not rt_clk_p   after 2.5 ns;
  rt_clk_n      <= not rt_clk_n   after 2.5 ns;
  rkta_clk_p    <= not rkta_clk_p after 4 ns;
  rkta_clk_n    <= not rkta_clk_n after 4 ns;
  rktb_clk_p    <= not rktb_clk_p after 4 ns;
  rktb_clk_n    <= not rktb_clk_n after 4 ns;
  prog_clk_p    <= not prog_clk_p after 3 ns;
  prog_clk_n    <= not prog_clk_n after 3 ns;
  host_clk      <= not host_clk   after 9 ns;
  glbl_reset_n  <= '1'            after 150 ns;
  hobit_reset_n <= '1'            after 120 ns;

  -- Disable the host bus as it is not necessary.
  host_cs_n <= '1';
  host_ad   <= (others => '0');
  host_par  <= '0';
  host_rw   <= '0';
  host_as   <= '0';

  top_inst : top
    port map (
      glbl_reset_n => glbl_reset_n,
      rt_clk_p     => rt_clk_p,
      rt_clk_n     => rt_clk_n,
      rkta_clk_p   => rkta_clk_p,
      rkta_clk_n   => rkta_clk_n,
      rktb_clk_p   => rktb_clk_p,
      rktb_clk_n   => rktb_clk_n,
      prog_clk_p   => prog_clk_p,
      prog_clk_n   => prog_clk_n,
      rt_rx_clk_p  => rt_rx_clk_p,
      rt_rx_clk_n  => rt_rx_clk_n,
      rt_rx_ctl_p  => rt_rx_ctl_p,
      rt_rx_ctl_n  => rt_rx_ctl_n,
      rt_rx_cad_p  => rt_rx_cad_p,
      rt_rx_cad_n  => rt_rx_cad_n,
      rt_rx_par_p  => rt_rx_par_p,
      rt_rx_par_n  => rt_rx_par_n,
      rt_tx_clk_p  => rt_tx_clk_p,
      rt_tx_clk_n  => rt_tx_clk_n,
      rt_tx_ctl_p  => rt_tx_ctl_p,
      rt_tx_ctl_n  => rt_tx_ctl_n,
      rt_tx_cad_p  => rt_tx_cad_p,
      rt_tx_cad_n  => rt_tx_cad_n,
      rt_tx_par_p  => rt_tx_par_p,
      rt_tx_par_n  => rt_tx_par_n,
      host_cs_n    => host_cs_n,
      host_as      => host_as,
      host_rw      => host_rw,
      host_par     => host_par,
      host_ad      => host_ad,
      host_int_n   => host_int_n,
      s_clock      => s_clock,
      s_data       => s_data,
      s_load       => s_load,
      np_load      => np_load,
      k_copy_out   => k_copy_out,
      k_copy_in    => k_copy_in,
      qdr_rfb_n_1  => qdr_rext_n_1_buf,
      qdr_dr_1     => qdr_dr_1,
      qdr_dw_1     => qdr_dw_1,
      qdr_sa_1     => qdr_sa_1,
      qdr_r_n_1    => qdr_r_n_1,
      qdr_w_n_1    => qdr_w_n_1,
      qdr_bw_n_1   => qdr_bw_n_1,
      qdr_k_1      => qdr_k_1,
      qdr_k_n_1    => qdr_k_n_1,
      qdr_cq_1     => qdr_cq_1,
      qdr_rext_n_1 => qdr_rext_n_1,
      qdr_doff_n_1 => qdr_doff_n_1,
      qdr_rfb_n_2  => qdr_rext_n_2_buf,
      qdr_dr_2     => qdr_dr_2,
      qdr_dw_2     => qdr_dw_2,
      qdr_sa_2     => qdr_sa_2,
      qdr_r_n_2    => qdr_r_n_2,
      qdr_w_n_2    => qdr_w_n_2,
      qdr_bw_n_2   => qdr_bw_n_2,
      qdr_k_2      => qdr_k_2,
      qdr_k_n_2    => qdr_k_n_2,
      qdr_cq_2     => qdr_cq_2,
      qdr_rext_n_2 => qdr_rext_n_2,
      qdr_doff_n_2 => qdr_doff_n_2,
      qdr_rfb_n_3  => qdr_rext_n_3_buf,
      qdr_dr_3     => qdr_dr_3,
      qdr_dw_3     => qdr_dw_3,
      qdr_sa_3     => qdr_sa_3,
      qdr_r_n_3    => qdr_r_n_3,
      qdr_w_n_3    => qdr_w_n_3,
      qdr_bw_n_3   => qdr_bw_n_3,
      qdr_k_3      => qdr_k_3,
      qdr_k_n_3    => qdr_k_n_3,
      qdr_cq_3     => qdr_cq_3,
      qdr_rext_n_3 => qdr_rext_n_3,
      qdr_doff_n_3 => qdr_doff_n_3,
      qdr_rfb_n_4  => qdr_rext_n_4_buf,
      qdr_dr_4     => qdr_dr_4,
      qdr_dw_4     => qdr_dw_4,
      qdr_sa_4     => qdr_sa_4,
      qdr_r_n_4    => qdr_r_n_4,
      qdr_w_n_4    => qdr_w_n_4,
      qdr_bw_n_4   => qdr_bw_n_4,
      qdr_k_4      => qdr_k_4,
      qdr_k_n_4    => qdr_k_n_4,
      qdr_cq_4     => qdr_cq_4,
      qdr_rext_n_4 => qdr_rext_n_4,
      qdr_doff_n_4 => qdr_doff_n_4);

  fabric_model_inst : fabric_model
    generic map (
      fabric_input  => fabric_input,
      fabric_output => fabric_output)
    port map (
      reset_n     => glbl_reset_n,
      ht_rx_clk_p => rt_tx_clk_p,
      ht_rx_clk_n => rt_tx_clk_n,
      ht_rx_ctl_p => rt_tx_ctl_p,
      ht_rx_ctl_n => rt_tx_ctl_n,
      ht_rx_cad_p => rt_tx_cad_p,
      ht_rx_cad_n => rt_tx_cad_n,
      ht_rx_par_p => rt_tx_par_p,
      ht_rx_par_n => rt_tx_par_n,
      ht_tx_clk_p => rt_rx_clk_p,
      ht_tx_clk_n => rt_rx_clk_n,
      ht_tx_ctl_p => rt_rx_ctl_p,
      ht_tx_ctl_n => rt_rx_ctl_n,
      ht_tx_cad_p => rt_rx_cad_p,
      ht_tx_cad_n => rt_rx_cad_n,
      ht_tx_par_p => rt_rx_par_p,
      ht_tx_par_n => rt_rx_par_n);

  -- The IOB delay of QDR outputs affects the relationship between
  -- the transmit and receive clocks. It must added into the
  -- functional simulation so that the simulation grabs the data in the
  -- correct clock phase.
  k_copy_in <= transport k_copy_out after fb_delay;

  qdr_k_1_buf      <= transport qdr_k_1      after iob_delay;
  qdr_k_n_1_buf    <= transport qdr_k_n_1    after iob_delay;
  qdr_dw_1_buf     <= transport qdr_dw_1     after iob_delay;
  qdr_sa_1_buf     <= transport qdr_sa_1     after iob_delay;
  qdr_r_n_1_buf    <= transport qdr_r_n_1    after iob_delay;
  qdr_w_n_1_buf    <= transport qdr_w_n_1    after iob_delay;
  qdr_bw_n_1_buf   <= transport qdr_bw_n_1   after iob_delay;
  qdr_rext_n_1_buf <= transport qdr_rext_n_1 after iob_delay;

  qdr_k_2_buf      <= transport qdr_k_2      after iob_delay;
  qdr_k_n_2_buf    <= transport qdr_k_n_2    after iob_delay;
  qdr_dw_2_buf     <= transport qdr_dw_2     after iob_delay;
  qdr_sa_2_buf     <= transport qdr_sa_2     after iob_delay;
  qdr_r_n_2_buf    <= transport qdr_r_n_2    after iob_delay;
  qdr_w_n_2_buf    <= transport qdr_w_n_2    after iob_delay;
  qdr_bw_n_2_buf   <= transport qdr_bw_n_2   after iob_delay;
  qdr_rext_n_2_buf <= transport qdr_rext_n_2 after iob_delay;

  qdr_k_3_buf      <= transport qdr_k_3      after iob_delay;
  qdr_k_n_3_buf    <= transport qdr_k_n_3    after iob_delay;
  qdr_dw_3_buf     <= transport qdr_dw_3     after iob_delay;
  qdr_sa_3_buf     <= transport qdr_sa_3     after iob_delay;
  qdr_r_n_3_buf    <= transport qdr_r_n_3    after iob_delay;
  qdr_w_n_3_buf    <= transport qdr_w_n_3    after iob_delay;
  qdr_bw_n_3_buf   <= transport qdr_bw_n_3   after iob_delay;
  qdr_rext_n_3_buf <= transport qdr_rext_n_3 after iob_delay;

  qdr_k_4_buf      <= transport qdr_k_4      after iob_delay;
  qdr_k_n_4_buf    <= transport qdr_k_n_4    after iob_delay;
  qdr_dw_4_buf     <= transport qdr_dw_4     after iob_delay;
  qdr_sa_4_buf     <= transport qdr_sa_4     after iob_delay;
  qdr_r_n_4_buf    <= transport qdr_r_n_4    after iob_delay;
  qdr_w_n_4_buf    <= transport qdr_w_n_4    after iob_delay;
  qdr_bw_n_4_buf   <= transport qdr_bw_n_4   after iob_delay;
  qdr_rext_n_4_buf <= transport qdr_rext_n_4 after iob_delay;
  
  cy7c1314_inst_1 : cy7c1314v18
    port map (
      d     => qdr_dw_1_buf,
      q     => qdr_dr_1,
      a     => qdr_sa_1_buf(17 downto 0),
      rps_n => qdr_r_n_1_buf,
      wps_n => qdr_w_n_1_buf,
      bws_n => qdr_bw_n_1_buf,
      k     => qdr_k_1_buf,
      k_n   => qdr_k_n_1_buf,
      c     => prog_clk_p,
      c_n   => prog_clk_n,
      cq    => qdr_cq_1,
      cq_n  => open);

  cy7c1314_inst_2 : cy7c1314v18
    port map (
      d     => qdr_dw_2_buf,
      q     => qdr_dr_2,
      a     => qdr_sa_2_buf(17 downto 0),
      rps_n => qdr_r_n_2_buf,
      wps_n => qdr_w_n_2_buf,
      bws_n => qdr_bw_n_2_buf,
      k     => qdr_k_2_buf,
      k_n   => qdr_k_n_2_buf,
      c     => prog_clk_p,
      c_n   => prog_clk_n,
      cq    => qdr_cq_2,
      cq_n  => open);

  cy7c1314_inst_3 : cy7c1314v18
    port map (
      d     => qdr_dw_3_buf,
      q     => qdr_dr_3,
      a     => qdr_sa_3_buf(17 downto 0),
      rps_n => qdr_r_n_3_buf,
      wps_n => qdr_w_n_3_buf,
      bws_n => qdr_bw_n_3_buf,
      k     => qdr_k_3_buf,
      k_n   => qdr_k_n_3_buf,
      c     => prog_clk_p,
      c_n   => prog_clk_n,
      cq    => qdr_cq_3,
      cq_n  => open);

  cy7c1314_inst_4 : cy7c1314v18
    port map (
      d     => qdr_dw_4_buf,
      q     => qdr_dr_4,
      a     => qdr_sa_4_buf(17 downto 0),
      rps_n => qdr_r_n_4_buf,
      wps_n => qdr_w_n_4_buf,
      bws_n => qdr_bw_n_4_buf,
      k     => qdr_k_4_buf,
      k_n   => qdr_k_n_4_buf,
      c     => prog_clk_p,
      c_n   => prog_clk_n,
      cq    => open,
      cq_n  => qdr_cq_4);               -- Matches schematic.


end architecture behave;

