--------------------------------------------------------------------------------
-- Copyright (c) 1995-2003 Xilinx, Inc.
-- All Right Reserved.
--------------------------------------------------------------------------------
--   ____  ____ 
--  /   /\/   / 
-- /___/  \  /    Vendor: Xilinx 
-- \   \   \/     Version : 7.1.04i
--  \   \         Application : ISE Foundation
--  /   /         Filename : pwm_tbw.vhw
-- /___/   /\     Timestamp : Thu Dec 14 16:59:23 2006
-- \   \  /  \ 
--  \___\/\___\ 
--
--Command: 
--Design Name: pwm_tbw
--Device: Xilinx
--

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_misc.all;
library work;
use work.user_pkg.all;
USE IEEE.STD_LOGIC_TEXTIO.ALL;
USE STD.TEXTIO.ALL;

ENTITY pwm_tbw IS
END pwm_tbw;

ARCHITECTURE testbench_arch OF pwm_tbw IS
    COMPONENT pwm
        PORT (
            reset_n : In std_logic;
            user_clk : In std_logic;
            stall : In std_logic;
            valid : In std_logic;
            data_in : In std_logic_vector (63 DownTo 0);
            index_in : In std_logic_vector (25 DownTo 0);
            data_out : Out std_logic_vector (37 DownTo 0);
            index_out : Out std_logic_vector (25 DownTo 0);
            data_out_valid : Out std_logic
        );
    END COMPONENT;

    SIGNAL reset_n : std_logic := '0';
    SIGNAL user_clk : std_logic := '0';
    SIGNAL stall : std_logic := '0';
    SIGNAL valid : std_logic := '0';
    SIGNAL data_in : std_logic_vector (63 DownTo 0) := "1000000010000000100000001000000010000000100000001000000010000000";
    SIGNAL index_in : std_logic_vector (25 DownTo 0) := "10000000000000000000000000";
    SIGNAL data_out : std_logic_vector (37 DownTo 0) := "00000000000000000000000000000000000000";
    SIGNAL index_out : std_logic_vector (25 DownTo 0) := "11111111111111111111111111";
    SIGNAL data_out_valid : std_logic := '0';

    SHARED VARIABLE TX_ERROR : INTEGER := 0;
    SHARED VARIABLE TX_OUT : LINE;

    constant PERIOD : time := 200 ns;
    constant DUTY_CYCLE : real := 0.5;
    constant OFFSET : time := 0 ns;

    BEGIN
        UUT : pwm
        PORT MAP (
            reset_n => reset_n,
            user_clk => user_clk,
            stall => stall,
            valid => valid,
            data_in => data_in,
            index_in => index_in,
            data_out => data_out,
            index_out => index_out,
            data_out_valid => data_out_valid
        );

        PROCESS    -- clock process for user_clk
        BEGIN
            WAIT for OFFSET;
            CLOCK_LOOP : LOOP
                user_clk <= '0';
                WAIT FOR (PERIOD - (PERIOD * DUTY_CYCLE));
                user_clk <= '1';
                WAIT FOR (PERIOD * DUTY_CYCLE);
            END LOOP CLOCK_LOOP;
        END PROCESS;

        PROCESS
            PROCEDURE CHECK_data_out(
                next_data_out : std_logic_vector (37 DownTo 0);
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (data_out /= next_data_out) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns data_out="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, data_out);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_data_out);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_data_out_valid(
                next_data_out_valid : std_logic;
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (data_out_valid /= next_data_out_valid) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns data_out_valid="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, data_out_valid);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_data_out_valid);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            PROCEDURE CHECK_index_out(
                next_index_out : std_logic_vector (25 DownTo 0);
                TX_TIME : INTEGER
            ) IS
                VARIABLE TX_STR : String(1 to 4096);
                VARIABLE TX_LOC : LINE;
                BEGIN
                IF (index_out /= next_index_out) THEN
                    STD.TEXTIO.write(TX_LOC, string'("Error at time="));
                    STD.TEXTIO.write(TX_LOC, TX_TIME);
                    STD.TEXTIO.write(TX_LOC, string'("ns index_out="));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, index_out);
                    STD.TEXTIO.write(TX_LOC, string'(", Expected = "));
                    IEEE.STD_LOGIC_TEXTIO.write(TX_LOC, next_index_out);
                    STD.TEXTIO.write(TX_LOC, string'(" "));
                    TX_STR(TX_LOC.all'range) := TX_LOC.all;
                    STD.TEXTIO.Deallocate(TX_LOC);
                    ASSERT (FALSE) REPORT TX_STR SEVERITY ERROR;
                    TX_ERROR := TX_ERROR + 1;
                END IF;
            END;
            BEGIN
                -- -------------  Current Time:  85ns
                WAIT FOR 85 ns;
                reset_n <= '1';
                -- -------------------------------------
                -- -------------  Current Time:  285ns
                WAIT FOR 200 ns;
                data_in <= "0000000010000000100000001000000010000000100000001000000010000000";
                -- -------------------------------------
                -- -------------  Current Time:  485ns
                WAIT FOR 200 ns;
                valid <= '1';
                data_in <= "0000000100000000100000001000000010000000100000001000000010000000";
                index_in <= "00000000000000000000000001";
                -- -------------------------------------
                -- -------------  Current Time:  685ns
                WAIT FOR 200 ns;
                data_in <= "0000001000000001000000001000000010000000100000001000000010000000";
                index_in <= "00000000000000000000000010";
                -- -------------------------------------
                -- -------------  Current Time:  885ns
                WAIT FOR 200 ns;
                data_in <= "0000001100000010000000010000000010000000100000001000000010000000";
                index_in <= "00000000000000000000000011";
                -- -------------------------------------
                -- -------------  Current Time:  1085ns
                WAIT FOR 200 ns;
                data_in <= "0000000000000011000000100000000100000000100000001000000010000000";
                index_in <= "00000000000000000000000100";
                -- -------------------------------------
                -- -------------  Current Time:  1285ns
                WAIT FOR 200 ns;
                data_in <= "0000000100000000000000110000001000000001000000001000000010000000";
                index_in <= "00000000000000000000000101";
                -- -------------------------------------
                -- -------------  Current Time:  1485ns
                WAIT FOR 200 ns;
                data_in <= "0000001000000001000000000000001100000010000000010000000010000000";
                index_in <= "00000000000000000000000110";
                -- -------------------------------------
                -- -------------  Current Time:  1685ns
                WAIT FOR 200 ns;
                data_in <= "0000001100000010000000010000000000000011000000100000000100000000";
                index_in <= "00000000000000000000000111";
                -- -------------------------------------
                -- -------------  Current Time:  1885ns
                WAIT FOR 200 ns;
                data_in <= "0000000000000011000000100000000100000000000000110000001000000001";
                index_in <= "00000000000000000000001000";
                -- -------------------------------------
                -- -------------  Current Time:  2085ns
                WAIT FOR 200 ns;
                data_in <= "0000000100000000000000110000001000000001000000000000001100000010";
                index_in <= "00000000000000000000001001";
                -- -------------------------------------
                -- -------------  Current Time:  2285ns
                WAIT FOR 200 ns;
                data_in <= "0000001000000001000000000000001100000010000000010000000000000011";
                index_in <= "00000000000000000000001010";
                -- -------------------------------------
                -- -------------  Current Time:  2485ns
                WAIT FOR 200 ns;
                data_in <= "0000001100000010000000010000000000000011000000100000000100000000";
                index_in <= "00000000000000000000001011";
                -- -------------------------------------
                -- -------------  Current Time:  2685ns
                WAIT FOR 200 ns;
                data_in <= "0000000000000011000000100000000100000000000000110000001000000001";
                index_in <= "00000000000000000000001100";
                -- -------------------------------------
                -- -------------  Current Time:  2715ns
                WAIT FOR 30 ns;
                CHECK_data_out_valid('1', 2715);
                CHECK_data_out("00000000000000000000000000010000011000", 2715);
                CHECK_index_out("00000000000000000000000111", 2715);
                -- -------------------------------------
                -- -------------  Current Time:  2885ns
                WAIT FOR 170 ns;
                data_in <= "0000000100000000000000110000001000000001000000000000001100000010";
                index_in <= "00000000000000000000001101";
                -- -------------------------------------
                -- -------------  Current Time:  2915ns
                WAIT FOR 30 ns;
                CHECK_data_out("00000000000000000000000000001101101100", 2915);
                CHECK_index_out("00000000000000000000001000", 2915);
                -- -------------------------------------
                -- -------------  Current Time:  3085ns
                WAIT FOR 170 ns;
                data_in <= "0000001000000001000000000000001100000010000000010000000000000011";
                index_in <= "00000000000000000000001110";
                -- -------------------------------------
                -- -------------  Current Time:  3115ns
                WAIT FOR 30 ns;
                CHECK_data_out("00000000000000000000000000001100010111", 3115);
                CHECK_index_out("00000000000000000000001001", 3115);
                -- -------------------------------------
                -- -------------  Current Time:  3285ns
                WAIT FOR 170 ns;
                data_in <= "0000001100000010000000010000000000000011000000100000000100000000";
                index_in <= "00000000000000000000001111";
                -- -------------------------------------
                -- -------------  Current Time:  3315ns
                WAIT FOR 30 ns;
                CHECK_data_out("00000000000000000000000000001111000011", 3315);
                CHECK_index_out("00000000000000000000001010", 3315);
                -- -------------------------------------
                -- -------------  Current Time:  3485ns
                WAIT FOR 170 ns;
                data_in <= "1000000000000011000000100000000100000000000000110000001000000001";
                index_in <= "00000000000000000000010000";
                -- -------------------------------------
                -- -------------  Current Time:  3515ns
                WAIT FOR 30 ns;
                CHECK_data_out("00000000000000000000000000010000011000", 3515);
                CHECK_index_out("00000000000000000000001011", 3515);
                -- -------------------------------------
                -- -------------  Current Time:  3685ns
                WAIT FOR 170 ns;
                data_in <= "1000000010000000000000110000001000000001000000000000001100000010";
                index_in <= "00000000000000000000010001";
                -- -------------------------------------
                -- -------------  Current Time:  3715ns
                WAIT FOR 30 ns;
                CHECK_data_out("00000000000000000000000000001101101100", 3715);
                CHECK_index_out("00000000000000000000001100", 3715);
                -- -------------------------------------
                -- -------------  Current Time:  3885ns
                WAIT FOR 170 ns;
                data_in <= "1000000010000000100000000000001100000010000000010000000000000011";
                index_in <= "00000000000000000000010010";
                -- -------------------------------------
                -- -------------  Current Time:  3915ns
                WAIT FOR 30 ns;
                CHECK_data_out("00000000000000000000000000001100010111", 3915);
                CHECK_index_out("00000000000000000000001101", 3915);
                -- -------------------------------------
                -- -------------  Current Time:  4085ns
                WAIT FOR 170 ns;
                data_in <= "1000000010000000100000001000000000000011000000100000000100000000";
                index_in <= "00000000000000000000010011";
                -- -------------------------------------
                -- -------------  Current Time:  4115ns
                WAIT FOR 30 ns;
                CHECK_data_out("00000000000000000000000000001111000011", 4115);
                CHECK_index_out("00000000000000000000001110", 4115);
                -- -------------------------------------
                -- -------------  Current Time:  4285ns
                WAIT FOR 170 ns;
                data_in <= "1000000010000000100000001000000010000000000000110000001000000001";
                index_in <= "00000000000000000000010100";
                -- -------------------------------------
                -- -------------  Current Time:  4315ns
                WAIT FOR 30 ns;
                CHECK_data_out("00000000000000000000000000010000011000", 4315);
                CHECK_index_out("00000000000000000000001111", 4315);
                -- -------------------------------------
                -- -------------  Current Time:  4485ns
                WAIT FOR 170 ns;
                data_in <= "1000000010000000100000001000000010000000100000000000001100000010";
                index_in <= "00000000000000000000010101";
                -- -------------------------------------
                -- -------------  Current Time:  4515ns
                WAIT FOR 30 ns;
                CHECK_data_out_valid('0', 4515);
                CHECK_data_out("00000000000000000000000000000000000000", 4515);
                CHECK_index_out("11111111111111111111111111", 4515);
                -- -------------------------------------
                -- -------------  Current Time:  4685ns
                WAIT FOR 170 ns;
                data_in <= "1000000010000000100000001000000010000000100000001000000000000011";
                index_in <= "00000000000000000000010110";
                -- -------------------------------------
                -- -------------  Current Time:  4885ns
                WAIT FOR 200 ns;
                valid <= '0';
                data_in <= "1000000010000000100000001000000010000000100000001000000010000000";
                index_in <= "10000000000000000000000000";
                -- -------------------------------------
                WAIT FOR 815 ns;

                IF (TX_ERROR = 0) THEN
                    STD.TEXTIO.write(TX_OUT, string'("No errors or warnings"));
                    ASSERT (FALSE) REPORT
                      "Simulation successful (not a failure).  No problems detected."
                      SEVERITY FAILURE;
                ELSE
                    STD.TEXTIO.write(TX_OUT, TX_ERROR);
                    STD.TEXTIO.write(TX_OUT,
                        string'(" errors found in simulation"));
                    ASSERT (FALSE) REPORT "Errors found during simulation"
                         SEVERITY FAILURE;
                END IF;
            END PROCESS;

    END testbench_arch;

